@@ -74,8 +74,8 @@ const Carousel = {
       const parent = el.parentNode;
       const theme = parent.getAttribute('class').split('theme-')[1];
       const themeCorrected = theme === 'light' || theme === 'space' ? theme : 'space';
-      const right = createElementFromHTML(`<img class='s-icon x2 right' src='${Icons.right[themeCorrected]}' alt='Suivant'>`);
-      const left = createElementFromHTML(`<img class='s-icon x2 left' src='${Icons.left[themeCorrected]}' alt='Précédent'>`);
+      const right = createElementFromHTML(`<img loading='lazy' class='s-icon x2 right' data-src='${Icons.right[themeCorrected]}' alt='Suivant'>`);
+      const left = createElementFromHTML(`<img loading='lazy' class='s-icon x2 left' data-src='${Icons.left[themeCorrected]}' alt='Précédent'>`);
       const scrollOffset = 305;
       parent.appendChild(right);
       parent.appendChild(left);
